@@ -30,11 +30,10 @@ from typing import Dict, List, Tuple
 import jsonlines
 import pendulum
 import requests
+from academic_observatory_workflows.config import schema_folder as default_schema_folder
 from airflow.api.common.experimental.pool import create_pool
 from airflow.exceptions import AirflowException
 from airflow.models.taskinstance import TaskInstance
-
-from academic_observatory_workflows.config import schema_folder as default_schema_folder
 from airflow.models.variable import Variable
 from observatory.platform.utils.airflow_utils import AirflowVars
 from observatory.platform.utils.gc_utils import (
@@ -43,7 +42,6 @@ from observatory.platform.utils.gc_utils import (
 )
 from observatory.platform.utils.proc_utils import wait_for_process
 from observatory.platform.utils.url_utils import retry_session
-from observatory.platform.utils.workflow_utils import upload_files_from_list
 from observatory.platform.workflows.snapshot_telescope import (
     SnapshotRelease,
     SnapshotTelescope,
@@ -289,7 +287,8 @@ class CrossrefFundrefTelescope(SnapshotTelescope):
         # doesn't exist
         releases_list_out = []
         for release in releases_list:
-            table_id = bigquery_sharded_table_id(CrossrefFundrefTelescope.DAG_ID, release["date"])
+            release_date = pendulum.parse(release["date"])
+            table_id = bigquery_sharded_table_id(CrossrefFundrefTelescope.DAG_ID, release_date)
             logging.info("Checking if bigquery table already exists:")
             if bigquery_table_exists(project_id, self.dataset_id, table_id):
                 logging.info(
@@ -297,7 +296,6 @@ class CrossrefFundrefTelescope(SnapshotTelescope):
                 )
             else:
                 logging.info(f"Table does not exist yet, processing {release['url']} in this workflow")
-                release["date"] = release["date"].format("YYYYMMDD")
                 releases_list_out.append(release)
 
         # If releases_list_out contains items then the DAG will continue (return True) otherwise it will
@@ -317,15 +315,6 @@ class CrossrefFundrefTelescope(SnapshotTelescope):
         for release in releases:
             release.download()
 
-    def upload_downloaded(self, releases: List[CrossrefFundrefRelease], **kwargs):
-        """Task to upload the downloaded releases.
-
-        :param releases: a list with Crossref Fundref releases.
-        :return: None.
-        """
-        for release in releases:
-            upload_files_from_list(release.download_files, release.download_bucket)
-
     def extract(self, releases: List[CrossrefFundrefRelease], **kwargs):
         """Task to extract the releases.
 
