@@ -304,7 +304,7 @@ class OrcidTelescope(StreamTelescope):
         )
         self.max_processes = max_processes
 
-        self.add_setup_task_chain([self.check_dependencies, self.get_release_info])
+        self.add_setup_task(self.check_dependencies)
         self.add_task_chain(
             [self.transfer, self.download_transferred, self.transform, self.upload_transformed, self.bq_load_partition]
         )
@@ -319,11 +319,11 @@ class OrcidTelescope(StreamTelescope):
         passed to this argument.
         :return: an OrcidRelease instance.
         """
-        ti: TaskInstance = kwargs["ti"]
-        start_date, end_date, first_release = ti.xcom_pull(key=OrcidTelescope.RELEASE_INFO, include_prior_dates=True)
+
+        start_date, end_date, first_release = self.get_release_info(**kwargs)
 
         release = OrcidRelease(
-            self.dag_id, pendulum.parse(start_date), pendulum.parse(end_date), first_release, self.max_processes
+            self.dag_id, start_date, end_date, first_release, self.max_processes
         )
         return release
 
@@ -378,7 +378,7 @@ def get_aws_conn_info() -> (str, str):
 
 
 def transform_single_file(download_path: str, transform_folder: str):
-    """ Transform a single ORCID file/record.
+    """Transform a single ORCID file/record.
     The xml file is turned into a dictionary, a record should have either a valid 'record' section or an 'error'
     section. The keys of the dictionary are slightly changed so they are valid BigQuery fields.
     The dictionary is appended to a jsonl file
