@@ -16,22 +16,24 @@
 
 import logging
 import os
+import shutil
 import unittest
 from pathlib import Path
 from unittest.mock import MagicMock, PropertyMock, patch
 
 import pendulum
-import vcr
+from airflow.exceptions import AirflowException
+from click.testing import CliRunner
+
 from academic_observatory_workflows.config import test_fixtures_folder
 from academic_observatory_workflows.workflows.grid_telescope import (
     GridRelease,
     GridTelescope,
     list_grid_records,
 )
-from airflow.exceptions import AirflowException
-from click.testing import CliRunner
-from observatory.platform.utils.file_utils import _hash_file, gzip_file_crc
+from observatory.platform.utils.file_utils import get_file_hash, gzip_file_crc
 from observatory.platform.utils.test_utils import (
+    HttpServer,
     ObservatoryEnvironment,
     ObservatoryTestCase,
     module_file_path,
@@ -78,6 +80,14 @@ def side_effect(arg):
     return values[arg]
 
 
+def copy_download_fixtures(*, mock, fixtures):
+    _, call_args = mock.call_args
+    src_filename = os.path.basename(call_args["url"])
+    src = os.path.join(fixtures, "files", src_filename)
+    dst = call_args["filename"]
+    shutil.copyfile(src, dst)
+
+
 @patch("observatory.platform.utils.workflow_utils.Variable.get")
 class TestGridTelescope(unittest.TestCase):
     """Tests for the functions used by the GRID telescope"""
@@ -93,45 +103,50 @@ class TestGridTelescope(unittest.TestCase):
         :param kwargs: keyword arguments.
         """
 
+        self.fixtures = test_fixtures_folder("grid")
+        self.httpserver = HttpServer(directory=self.fixtures)
+        self.httpserver.start()
+
         super(TestGridTelescope, self).__init__(*args, **kwargs)
+
         # Telescope instance
         self.grid = GridTelescope()
 
         # Paths
-        self.vcr_cassettes_path = test_fixtures_folder("grid")
-        self.list_grid_records_path = os.path.join(self.vcr_cassettes_path, "list_grid_releases.yaml")
-
         # Contains GRID releases 2015-09-22 and 2015-10-09 (format for both is .csv and .json files)
-        with patch("observatory.platform.utils.workflow_utils.Variable.get") as mock_variable_get:
-            mock_variable_get.side_effect = side_effect
-            self.grid_run_2015_10_18 = {
-                "start_date": pendulum.datetime(2015, 10, 11),
-                "end_date": pendulum.datetime(2015, 10, 18),
-                "records": [
-                    {"article_ids": [1570968, 1570967], "release_date": "2015-10-09"},
-                    {"article_ids": [1553266, 1553267], "release_date": "2015-09-22"},
-                ],
-                # there are 2 releases in this run, but use only 1 for testing
-                "release": GridRelease(
-                    self.grid.dag_id, ["1553266", "1553267"], pendulum.parse("2015-09-22T00:00:00+00:00")
-                ),
-                "download_path": os.path.join(self.vcr_cassettes_path, "grid_2015-09-22.yaml"),
-                "download_hash": "c6fd33fd31b6699a2f19622f0283f4f1",
-                "extract_hash": "c6fd33fd31b6699a2f19622f0283f4f1",
-                "transform_crc": "eb66ae78",
-            }
+        with patch.object(
+            GridTelescope,
+            "GRID_FILE_URL",
+            f"http://{self.httpserver.host}:{self.httpserver.port}" + "/v2/articles/{article_id}/files",
+        ):
+            with patch("observatory.platform.utils.workflow_utils.Variable.get") as mock_variable_get:
+                mock_variable_get.side_effect = side_effect
+                self.grid_run_2015_10_18 = {
+                    "start_date": pendulum.datetime(2015, 10, 11),
+                    "end_date": pendulum.datetime(2015, 10, 18),
+                    "records": [
+                        {"article_ids": [1570967, 1570968], "release_date": "2015-10-09"},
+                        {"article_ids": [1553267, 1553266], "release_date": "2015-09-22"},
+                    ],
+                    # there are 2 releases in this run, but use only 1 for testing
+                    "release": GridRelease(
+                        self.grid.dag_id, ["1553266", "1553267"], pendulum.parse("2015-09-22T00:00:00+00:00")
+                    ),
+                    "download_hash": "c6fd33fd31b6699a2f19622f0283f4f1",
+                    "extract_hash": "c6fd33fd31b6699a2f19622f0283f4f1",
+                    "transform_crc": "eb66ae78",
+                }
 
-            # Contains GRID release 2020-03-15 (format is a .zip file, which is more common)
-            self.grid_run_2020_03_27 = {
-                "start_date": pendulum.datetime(2020, 3, 20),
-                "end_date": pendulum.datetime(2020, 3, 27),
-                "records": [{"article_ids": [12022722], "release_date": "2020-03-15T00:00:00+00:00"}],
-                "release": GridRelease(self.grid.dag_id, ["12022722"], pendulum.parse("2020-03-15T00:00:00+00:00")),
-                "download_path": os.path.join(self.vcr_cassettes_path, "grid_2020-03-15.yaml"),
-                "download_hash": "3d300affce1666ac50b8d945c6ca4c5a",
-                "extract_hash": "5aff68e9bf72e846a867e91c1fa206a0",
-                "transform_crc": "77bc8585",
-            }
+                # Contains GRID release 2020-03-15 (format is a .zip file, which is more common)
+                self.grid_run_2020_03_27 = {
+                    "start_date": pendulum.datetime(2020, 3, 20),
+                    "end_date": pendulum.datetime(2020, 3, 27),
+                    "records": [{"article_ids": [12022722], "release_date": "2020-03-15T00:00:00+00:00"}],
+                    "release": GridRelease(self.grid.dag_id, ["12022722"], pendulum.parse("2020-03-15T00:00:00+00:00")),
+                    "download_hash": "3d300affce1666ac50b8d945c6ca4c5a",
+                    "extract_hash": "5aff68e9bf72e846a867e91c1fa206a0",
+                    "transform_crc": "77bc8585",
+                }
 
         self.grid_runs = [self.grid_run_2015_10_18, self.grid_run_2020_03_27]
 
@@ -139,6 +154,9 @@ class TestGridTelescope(unittest.TestCase):
         logging.basicConfig()
         logging.getLogger().setLevel(logging.WARNING)
 
+    def __del__(self):
+        self.httpserver.stop()
+
     def test_ctor(self, mock_variable_get):
         """Cover case where airflow_vars is given."""
         telescope = GridTelescope(airflow_vars=[])
@@ -150,7 +168,11 @@ class TestGridTelescope(unittest.TestCase):
         :param mock_variable_get: Mock result of airflow's Variable.get() function
         :return: None.
         """
-        with vcr.use_cassette(self.list_grid_records_path):
+        with patch.object(
+            GridTelescope,
+            "GRID_DATASET_URL",
+            f"http://{self.httpserver.host}:{self.httpserver.port}/list_grid_releases",
+        ):
             start_date = self.grid_run_2015_10_18["start_date"]
             end_date = self.grid_run_2015_10_18["end_date"]
             records = list_grid_records(start_date, end_date, GridTelescope.GRID_DATASET_URL)
@@ -197,7 +219,8 @@ class TestGridTelescope(unittest.TestCase):
             for release in releases:
                 self.assertIsInstance(release, GridRelease)
 
-    def test_download_release(self, mock_variable_get):
+    @patch("academic_observatory_workflows.workflows.grid_telescope.download_file")
+    def test_download_release(self, m_download, mock_variable_get):
         """Download two specific GRID releases and check they have the expected md5 sum.
 
         :param mock_variable_get: Mock result of airflow's Variable.get() function
@@ -208,17 +231,24 @@ class TestGridTelescope(unittest.TestCase):
         with CliRunner().isolated_filesystem():
             for run in self.grid_runs:
                 release = run["release"]
-                with vcr.use_cassette(run["download_path"]):
-                    downloads = release.download()
-                    # Check that returned downloads has correct length
-                    self.assertEqual(1, len(downloads))
+                downloads = release.download()
+                # Check that returned downloads has correct length
+                self.assertEqual(1, len(downloads))
 
-                    # Check that file has expected hash
-                    file_path = downloads[0]
-                    self.assertTrue(os.path.exists(file_path))
-                    self.assertEqual(run["download_hash"], _hash_file(file_path, algorithm="md5"))
+            self.assertEqual(m_download.call_count, 2)
 
-    def test_extract_release(self, mock_variable_get):
+            _, call_args = m_download.call_args_list[0]
+            self.assertEqual(call_args["url"], "https://ndownloader.figshare.com/files/2284777")
+            self.assertEqual(call_args["filename"], "data/telescopes/download/grid/grid_2015_09_22/grid.json")
+            self.assertEqual(call_args["hash"], "c6fd33fd31b6699a2f19622f0283f4f1")
+
+            _, call_args = m_download.call_args_list[1]
+            self.assertEqual(call_args["url"], "https://ndownloader.figshare.com/files/22091379")
+            self.assertEqual(call_args["filename"], "data/telescopes/download/grid/grid_2020_03_15/grid.zip")
+            self.assertEqual(call_args["hash"], "3d300affce1666ac50b8d945c6ca4c5a")
+
+    @patch("academic_observatory_workflows.workflows.grid_telescope.download_file")
+    def test_extract_release(self, m_download, mock_variable_get):
         """Test that the GRID releases are extracted as expected, both for an unzipped json file and a zip file.
 
         :param mock_variable_get: Mock result of airflow's Variable.get() function
@@ -229,14 +259,21 @@ class TestGridTelescope(unittest.TestCase):
         with CliRunner().isolated_filesystem():
             for run in self.grid_runs:
                 release = run["release"]
-                with vcr.use_cassette(run["download_path"]):
-                    release.download()
-                    release.extract()
 
-                    self.assertEqual(1, len(release.extract_files))
-                    self.assertEqual(run["extract_hash"], _hash_file(release.extract_files[0], algorithm="md5"))
+                release.download()
 
-    def test_transform_release(self, mock_variable_get):
+                # Copy the file in rather than download
+                copy_download_fixtures(mock=m_download, fixtures=self.fixtures)
+
+                release.extract()
+
+                self.assertEqual(1, len(release.extract_files))
+                self.assertEqual(
+                    run["extract_hash"], get_file_hash(file_path=release.extract_files[0], algorithm="md5")
+                )
+
+    @patch("academic_observatory_workflows.workflows.grid_telescope.download_file")
+    def test_transform_release(self, m_download, mock_variable_get):
         """Test that the GRID releases are transformed as expected.
 
         :param mock_variable_get: Mock result of airflow's Variable.get() function
@@ -247,13 +284,17 @@ class TestGridTelescope(unittest.TestCase):
         with CliRunner().isolated_filesystem():
             for run in self.grid_runs:
                 release = run["release"]
-                with vcr.use_cassette(run["download_path"]):
-                    release.download()
-                    release.extract()
-                    release.transform()
 
-                    self.assertEqual(1, len(release.transform_files))
-                    self.assertEqual(run["transform_crc"], gzip_file_crc(release.transform_files[0]))
+                release.download()
+
+                # Copy the file in rather than download
+                copy_download_fixtures(mock=m_download, fixtures=self.fixtures)
+
+                release.extract()
+                release.transform()
+
+                self.assertEqual(1, len(release.transform_files))
+                self.assertEqual(run["transform_crc"], gzip_file_crc(release.transform_files[0]))
 
 
 class TestGridRelease(unittest.TestCase):
@@ -292,13 +333,21 @@ class TestGridTelescopeDag(ObservatoryTestCase):
         """
         super().__init__(*args, **kwargs)
 
+        self.fixtures = test_fixtures_folder("grid")
         self.project_id = os.environ["TEST_GCP_PROJECT_ID"]
         self.data_location = os.environ["TEST_GCP_DATA_LOCATION"]
 
         # Paths
-        self.vcr_cassettes_path = os.path.join(test_fixtures_folder(), "grid")
-        self.list_grid_records_path = os.path.join(self.vcr_cassettes_path, "list_grid_releases.yaml")
-        self.grid_path = os.path.join(self.vcr_cassettes_path, "grid_2015-09-22.yaml")
+        self.fixtures = test_fixtures_folder("grid")
+        self.httpserver = HttpServer(directory=self.fixtures)
+        self.httpserver.start()
+
+        # GridTelescope.GRID_FILE_URL = (
+        #     f"http://{self.httpserver.host}:{self.httpserver.port}" + "/v2/articles/{article_id}/files"
+        # )
+
+    def __del__(self):
+        self.httpserver.stop()
 
     def setup_observatory_environment(self):
         env = ObservatoryEnvironment(self.project_id, self.data_location)
@@ -338,7 +387,8 @@ class TestGridTelescopeDag(ObservatoryTestCase):
             dag_file = os.path.join(module_file_path("academic_observatory_workflows.dags"), "grid_telescope.py")
             self.assert_dag_load("grid", dag_file)
 
-    def test_telescope(self):
+    @patch("academic_observatory_workflows.workflows.grid_telescope.download_file")
+    def test_telescope(self, m_download):
         """Test running the telescope. Functional test."""
 
         env = self.setup_observatory_environment()
@@ -349,85 +399,90 @@ class TestGridTelescopeDag(ObservatoryTestCase):
         # Create the Observatory environment and run tests
         with env.create():
             with env.create_dag_run(dag, execution_date):
-                # Check dependencies
-                env.run_task(telescope.check_dependencies.__name__, dag, execution_date)
+                with patch.object(
+                    GridTelescope,
+                    "GRID_FILE_URL",
+                    f"http://{self.httpserver.host}:{self.httpserver.port}" + "/v2/articles/{article_id}/files",
+                ):
+                    # Check dependencies
+                    env.run_task(telescope.check_dependencies.__name__, dag, execution_date)
 
-                # List releases
-                with patch(
-                    "academic_observatory_workflows.workflows.grid_telescope.list_grid_records"
-                ) as m_list_grid_records:
-                    m_list_grid_records.return_value = [
-                        {"article_ids": [1553266, 1553267], "release_date": "2015-10-09"},
-                    ]
-                    ti = env.run_task(telescope.list_releases.__name__, dag, execution_date)
+                    # List releases
+                    with patch(
+                        "academic_observatory_workflows.workflows.grid_telescope.list_grid_records"
+                    ) as m_list_grid_records:
+                        m_list_grid_records.return_value = [
+                            {"article_ids": [1553266, 1553267], "release_date": "2015-10-09"},
+                        ]
+                        ti = env.run_task(telescope.list_releases.__name__, dag, execution_date)
 
-                # Test list releases
-                available_releases = ti.xcom_pull(
-                    key=GridTelescope.RELEASE_INFO,
-                    task_ids=telescope.list_releases.__name__,
-                    include_prior_dates=False,
-                )
-                self.assertEqual(len(available_releases), 1)
+                        # Test list releases
+                        available_releases = ti.xcom_pull(
+                            key=GridTelescope.RELEASE_INFO,
+                            task_ids=telescope.list_releases.__name__,
+                            include_prior_dates=False,
+                        )
+                        self.assertEqual(len(available_releases), 1)
 
-                # Download
-                with vcr.use_cassette(self.grid_path):
-                    env.run_task(telescope.download.__name__, dag, execution_date)
+                        # Download
+                        env.run_task(telescope.download.__name__, dag, execution_date)
+                        copy_download_fixtures(mock=m_download, fixtures=self.fixtures)
 
-                # Test download
-                release = GridRelease(
-                    dag_id="grid",
-                    article_ids=[1553266, 1553267],
-                    release_date=pendulum.datetime(2015, 10, 9),
-                )
-                self.assertEqual(len(release.download_files), 1)
+                        # Test download
+                        release = GridRelease(
+                            dag_id="grid",
+                            article_ids=[1553266, 1553267],
+                            release_date=pendulum.datetime(2015, 10, 9),
+                        )
+                        self.assertEqual(len(release.download_files), 1)
 
-                # upload_downloaded
-                env.run_task(telescope.upload_downloaded.__name__, dag, execution_date)
+                        # upload_downloaded
+                        env.run_task(telescope.upload_downloaded.__name__, dag, execution_date)
 
-                # Test upload_downloaded
-                for file in release.download_files:
-                    self.assert_blob_integrity(env.download_bucket, blob_name(file), file)
+                        # Test upload_downloaded
+                        for file in release.download_files:
+                            self.assert_blob_integrity(env.download_bucket, blob_name(file), file)
 
-                # extract
-                env.run_task(telescope.extract.__name__, dag, execution_date)
+                        # extract
+                        env.run_task(telescope.extract.__name__, dag, execution_date)
 
-                # Test extract
-                self.assertEqual(len(release.extract_files), 1)
+                        # Test extract
+                        self.assertEqual(len(release.extract_files), 1)
 
-                # transform
-                env.run_task(telescope.transform.__name__, dag, execution_date)
+                        # transform
+                        env.run_task(telescope.transform.__name__, dag, execution_date)
 
-                # Test transform
-                self.assertEqual(len(release.transform_files), 1)
+                        # Test transform
+                        self.assertEqual(len(release.transform_files), 1)
 
-                # upload_transformed
-                env.run_task(telescope.upload_transformed.__name__, dag, execution_date)
+                        # upload_transformed
+                        env.run_task(telescope.upload_transformed.__name__, dag, execution_date)
 
-                # Test upload_transformed
-                for file in release.transform_files:
-                    self.assert_blob_integrity(env.transform_bucket, blob_name(file), file)
+                        # Test upload_transformed
+                        for file in release.transform_files:
+                            self.assert_blob_integrity(env.transform_bucket, blob_name(file), file)
 
-                # bq_load
-                env.run_task(telescope.bq_load.__name__, dag, execution_date)
+                        # bq_load
+                        env.run_task(telescope.bq_load.__name__, dag, execution_date)
 
-                # Test bq_load
-                # Will only check table exists rather than validate data.
-                for file in release.transform_files:
-                    table_id, _ = table_ids_from_path(file)
-                    suffix = release.release_date.format("YYYYMMDD")
-                    table_id = f"{self.project_id}.{self.dataset_id}.{table_id}{suffix}"
-                    expected_rows = 48987
-                    self.assert_table_integrity(table_id, expected_rows)
+                        # Test bq_load
+                        # Will only check table exists rather than validate data.
+                        for file in release.transform_files:
+                            table_id, _ = table_ids_from_path(file)
+                            suffix = release.release_date.format("YYYYMMDD")
+                            table_id = f"{self.project_id}.{self.dataset_id}.{table_id}{suffix}"
+                            expected_rows = 48987
+                            self.assert_table_integrity(table_id, expected_rows)
 
-                # cleanup
-                env.run_task(telescope.cleanup.__name__, dag, execution_date)
+                        # cleanup
+                        env.run_task(telescope.cleanup.__name__, dag, execution_date)
 
-                # Test cleanup
-                # Test that all telescope data deleted
-                download_folder, extract_folder, transform_folder = (
-                    release.download_folder,
-                    release.extract_folder,
-                    release.transform_folder,
-                )
-                env.run_task(telescope.cleanup.__name__, dag, execution_date)
-                self.assert_cleanup(download_folder, extract_folder, transform_folder)
+                        # Test cleanup
+                        # Test that all telescope data deleted
+                        download_folder, extract_folder, transform_folder = (
+                            release.download_folder,
+                            release.extract_folder,
+                            release.transform_folder,
+                        )
+                        env.run_task(telescope.cleanup.__name__, dag, execution_date)
+                        self.assert_cleanup(download_folder, extract_folder, transform_folder)
