@@ -15,10 +15,10 @@
 
 # Author: Aniek Roelofs, James Diprose
 
-# Crossref Metadata (pigz mawk), Unpaywall (unzip), Open Citations (unzip)
-apt-get install pigz mawk unzip -y
+# Crossref Metadata (pigz), Open Citations (unzip)
+apt-get install pigz unzip -y
 
 # ORCID: install Google Cloud SDK as root user, used in
-RUN echo "deb [signed-by=/usr/share/keyrings/cloud.google.gpg] http://packages.cloud.google.com/apt cloud-sdk main" | \
+echo "deb [signed-by=/usr/share/keyrings/cloud.google.gpg] http://packages.cloud.google.com/apt cloud-sdk main" | \
 tee -a /etc/apt/sources.list.d/google-cloud-sdk.list && curl https://packages.cloud.google.com/apt/doc/apt-key.gpg | \
 apt-key --keyring /usr/share/keyrings/cloud.google.gpg  add - && apt-get update -y && apt-get install google-cloud-sdk -y
